==> duiba-service-api-1.1-20160608.102723-128-sources.jar: cn/com/duiba/service/domain/dataobject/AppExtraDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class AppExtraDO extends BaseDO {

	private Long id;

	private Long appId;

	private String shareLogo;

	private String shareButtonName;

	private String shareAndroidLink;

	private String shareIosLink;

	private String wakeupAppLink;

	private Date gmtCreate;

	private Date gmtModified;
	
	private String alarmPhone;
	
	private String entranceDesc;
	
	private String callLoginProgram;
	private String appPerson;

	public String getCallLoginProgram() {
		return callLoginProgram;
	}

	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}

	public AppExtraDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;

			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	public AppExtraDO() {
	}

	public AppExtraDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getShareLogo() {
		return shareLogo;
	}

	public void setShareLogo(String shareLogo) {
		this.shareLogo = shareLogo;
	}

	public String getShareButtonName() {
		return shareButtonName;
	}

	public void setShareButtonName(String shareButtonName) {
		this.shareButtonName = shareButtonName;
	}

	public String getShareAndroidLink() {
		return shareAndroidLink;
	}

	public void setShareAndroidLink(String shareAndroidLink) {
		this.shareAndroidLink = shareAndroidLink;
	}

	public String getShareIosLink() {
		return shareIosLink;
	}

	public void setShareIosLink(String shareIosLink) {
		this.shareIosLink = shareIosLink;
	}

	public String getWakeupAppLink() {
		return wakeupAppLink;
	}

	public void setWakeupAppLink(String wakeupAppLink) {
		this.wakeupAppLink = wakeupAppLink;
	}

	public String getAlarmPhone() {
		return alarmPhone;
	}

	public void setAlarmPhone(String alarmPhone) {
		this.alarmPhone = alarmPhone;
	}
	
	public String getEntranceDesc() {
		return entranceDesc;
	}

	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	
	public String getAppPerson() {
		return appPerson;
	}

	public void setAppPerson(String appPerson) {
		this.appPerson = appPerson;
	}
}

==> duiba-service-api-1.7.7.4-sources.jar: cn/com/duiba/service/domain/dataobject/AppExtraDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class AppExtraDO extends BaseDO {
	private static final long serialVersionUID = 2312323215L;

	private Long id;

	private Long appId;

	private String shareLogo;

	private String shareButtonName;

	private String shareAndroidLink;

	private String shareIosLink;

	private String wakeupAppLink;

	private Date gmtCreate;

	private Date gmtModified;
	
	private String alarmPhone;
	
	private String entranceDesc;
	
	private String callLoginProgram;
	private String appPerson;
	private String appType;
	
	private String shareLandUrl;
	private Boolean isInfoGet;
	private String shareImage;
    private Boolean isDuibaShare;
    private String shareAndroidLinkActivity;
    private String shareIosLinkActivity;
    
    public String getShareAndroidLinkActivity() {
        return shareAndroidLinkActivity;
    }
    
    public void setShareAndroidLinkActivity(String shareAndroidLinkActivity) {
        this.shareAndroidLinkActivity = shareAndroidLinkActivity;
    }
    
    public String getShareIosLinkActivity() {
        return shareIosLinkActivity;
    }
    
    public void setShareIosLinkActivity(String shareIosLinkActivity) {
        this.shareIosLinkActivity = shareIosLinkActivity;
    }

    public String getShareImage() {
        return shareImage;
    }
    
    public void setShareImage(String shareImage) {
        this.shareImage = shareImage;
    }
    
    public Boolean getIsDuibaShare() {
        return isDuibaShare;
    }

    public void setIsDuibaShare(Boolean isDuibaShare) {
        this.isDuibaShare = isDuibaShare;
    }

    public String getShareLandUrl() {
        return shareLandUrl;
    }
    
    public void setShareLandUrl(String shareLandUrl) {
        this.shareLandUrl = shareLandUrl;
    }

    public Boolean getIsInfoGet() {
        return isInfoGet;
    }
    
    public void setIsInfoGet(Boolean isInfoGet) {
        this.isInfoGet = isInfoGet;
    }

    public String getAppType() {
        return appType;
    }
    
    public void setAppType(String appType) {
        this.appType = appType;
    }

    public String getCallLoginProgram() {
		return callLoginProgram;
	}

	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}

	public AppExtraDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;

			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	public AppExtraDO() {
	}

	public AppExtraDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public String getShareLogo() {
		return shareLogo;
	}

	public void setShareLogo(String shareLogo) {
		this.shareLogo = shareLogo;
	}

	public String getShareButtonName() {
		return shareButtonName;
	}

	public void setShareButtonName(String shareButtonName) {
		this.shareButtonName = shareButtonName;
	}

	public String getShareAndroidLink() {
		return shareAndroidLink;
	}

	public void setShareAndroidLink(String shareAndroidLink) {
		this.shareAndroidLink = shareAndroidLink;
	}

	public String getShareIosLink() {
		return shareIosLink;
	}

	public void setShareIosLink(String shareIosLink) {
		this.shareIosLink = shareIosLink;
	}

	public String getWakeupAppLink() {
		return wakeupAppLink;
	}

	public void setWakeupAppLink(String wakeupAppLink) {
		this.wakeupAppLink = wakeupAppLink;
	}

	public String getAlarmPhone() {
		return alarmPhone;
	}

	public void setAlarmPhone(String alarmPhone) {
		this.alarmPhone = alarmPhone;
	}
	
	public String getEntranceDesc() {
		return entranceDesc;
	}

	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	
	public String getAppPerson() {
		return appPerson;
	}

	public void setAppPerson(String appPerson) {
		this.appPerson = appPerson;
	}
}
